@@ -31,11 +31,6 @@ struct object {
 	int fd;
 };
 
-#define obj_list(obj,i) \
-((struct record*)(obj->q->list + (sizeof(struct record) + obj->rec_len)*i))
-
-
-//struct record* obj_list(struct object*,int);
 struct object* new_queue();
 int    init_file(const char*,int,int*);
 void   free_queue(struct object*);
@@ -47,5 +42,6 @@ void unlock_queue(struct object*);
 void push_queue(struct object*,const char*,int);
 SV*  pop_queue(struct object*);
 SV*  top_queue(struct object*);
+void drop_queue(struct object*);
 
 #endif
